@@ -16,12 +16,12 @@
 */
 
 #include "addressline/completionorder/completionordereditor.h"
-#include "addresseelineeditstatic.h"
+#include "addresseelineeditmanager.h"
 #include "addresseelineedit_p.h"
 #include "addresseelineedit.h"
 #include "kmailcompletion.h"
 #include "libkdepimakonadi_debug.h"
-#include "helper_p.h"
+
 #include <QMap>
 #include <QTimer>
 #include <kcolorscheme.h>
@@ -41,60 +41,42 @@
 #include <ldap/ldapclientsearch.h>
 #include <addressline/addresslineedit/baloocompletionemail.h>
 #include <akonadi/contact/contactsearchjob.h>
-#include <QNetworkConfigurationManager>
 
-#include <addressline/blacklistbaloocompletion/blacklistbalooemailcompletiondialog.h>
-static QNetworkConfigurationManager *s_networkConfigMgr = nullptr;
-
-namespace KPIM
-{
-Q_GLOBAL_STATIC(AddresseeLineEditStatic, s_static)
+namespace KPIM {
 AddresseeLineEditPrivate::AddresseeLineEditPrivate(KPIM::AddresseeLineEdit *qq, bool enableCompletion)
-    : QObject(qq),
-      q(qq),
-      m_recentAddressConfig(nullptr),
-      m_useCompletion(enableCompletion),
-      m_completionInitialized(false),
-      m_smartPaste(false),
-      m_addressBookConnected(false),
-      m_lastSearchMode(false),
-      m_searchExtended(false),
-      m_useSemicolonAsSeparator(false),
-      m_showOU(false),
-      m_enableBalooSearch(true),
-      m_enableAkonadiSearch(true),
-      mExpandIntern(true),
-      mAutoGroupExpand(false),
-      mShowRecentAddresses(true),
-      mCanDeleteLineEdit(true)
+    : QObject(qq)
+    , q(qq)
+    , m_recentAddressConfig(nullptr)
+    , m_useCompletion(enableCompletion)
+    , m_completionInitialized(false)
+    , m_smartPaste(false)
+    , m_addressBookConnected(false)
+    , m_lastSearchMode(false)
+    , m_searchExtended(false)
+    , m_useSemicolonAsSeparator(false)
+    , m_showOU(false)
+    , m_enableBalooSearch(true)
+    , m_enableAkonadiSearch(true)
+    , mExpandIntern(true)
+    , mAutoGroupExpand(false)
+    , mShowRecentAddresses(true)
+    , mCanDeleteLineEdit(true)
 {
-    if (!s_networkConfigMgr) {
-        s_networkConfigMgr = new QNetworkConfigurationManager(QCoreApplication::instance());
-    }
-
     m_delayedQueryTimer.setSingleShot(true);
     connect(&m_delayedQueryTimer, &QTimer::timeout, this, &AddresseeLineEditPrivate::slotTriggerDelayedQueries);
-
 }
 
 AddresseeLineEditPrivate::~AddresseeLineEditPrivate()
 {
-    if (s_static->ldapSearch && s_static->ldapLineEdit == q) {
-        stopLDAPLookup();
+    if (AddresseeLineEditManager::self()->ldapSearch() && AddresseeLineEditManager::self()->addressLineEdit() == q) {
+        AddresseeLineEditManager::self()->stopLDAPLookup();
     }
 }
 
 void AddresseeLineEditPrivate::restartTime(const QString &searchString)
 {
-    if (useCompletion() && s_static->ldapTimer) {
-        if (s_static->ldapText != searchString || s_static->ldapLineEdit != q) {
-            stopLDAPLookup();
-        }
-
-        s_static->ldapText = searchString;
-        s_static->ldapLineEdit = q;
-        s_static->ldapTimer->setSingleShot(true);
-        s_static->ldapTimer->start(500);
+    if (useCompletion()) {
+        AddresseeLineEditManager::self()->restartLdap(searchString, q);
     }
 }
 
@@ -104,10 +86,10 @@ class SourceWithWeight
 {
 public:
     int weight;           // the weight of the source
-    int index;            // index into s_static->completionSources
+    int index;            // index into AddresseeLineEditStatic::self()->completionSources
     QString sourceName;   // the name of the source, e.g. "LDAP Server"
 
-    bool operator< (const SourceWithWeight &other) const
+    bool operator<(const SourceWithWeight &other) const
     {
         if (weight > other.weight) {
             return true;
@@ -133,39 +115,18 @@ void AddresseeLineEditPrivate::init()
     m_toolButton->setStyleSheet(QStringLiteral("QToolButton { border: none; }"));
     connect(m_toolButton, &QToolButton::clicked, q, &AddresseeLineEdit::iconClicked);
 
-    if (!s_static.exists()) {
-        s_static->completion->setOrder(KCompletion::Weighted);
-        s_static->completion->setIgnoreCase(true);
+    if (!AddresseeLineEditManager::self()) {
+        AddresseeLineEditManager::self()->completion()->setOrder(KCompletion::Weighted);
+        AddresseeLineEditManager::self()->completion()->setIgnoreCase(true);
     }
 
     if (m_useCompletion) {
-        if (!s_static->ldapTimer) {
-            s_static->ldapTimer = new QTimer;
-            s_static->ldapSearch = new KLDAP::LdapClientSearch;
+        AddresseeLineEditManager::self()->initializeLdap();
+        AddresseeLineEditManager::self()->setBalooCompletionSource(q->addCompletionSource(i18nc("@title:group", "Contacts found in your data"), -1));
 
-            /* The reasoning behind this filter is:
-             * If it's a person, or a distlist, show it, even if it doesn't have an email address.
-             * If it's not a person, or a distlist, only show it if it has an email attribute.
-             * This allows both resource accounts with an email address which are not a person and
-             * person entries without an email address to show up, while still not showing things
-             * like structural entries in the ldap tree.
-             */
-
-#if 0
-            s_static->ldapSearch->setFilter(QStringLiteral("&(|(objectclass=person)(objectclass=groupOfNames)(mail=*))"
-                                            "(|(cn=%1*)(mail=%1*)(mail=*@%1*)(givenName=%1*)(sn=%1*))"));
-#endif
-            //Fix bug 323272 "Exchange doesn't like any queries beginning with *."
-            s_static->ldapSearch->setFilter(QStringLiteral("&(|(objectclass=person)(objectclass=groupOfNames)(mail=*))"
-                                            "(|(cn=%1*)(mail=%1*)(givenName=%1*)(sn=%1*))"));
-
-        }
-
-        s_static->balooCompletionSource = q->addCompletionSource(i18nc("@title:group", "Contacts found in your data"), -1);
-
-        s_static->updateLDAPWeights();
+        AddresseeLineEditManager::self()->updateLDAPWeights();
         if (!m_completionInitialized) {
-            q->setCompletionObject(s_static->completion, false);
+            q->setCompletionObject(AddresseeLineEditManager::self()->completion(), false);
             connect(q, &KLineEdit::completion,
                     this, &AddresseeLineEditPrivate::slotCompletion);
             connect(q, SIGNAL(returnPressed(QString)),
@@ -176,8 +137,8 @@ void AddresseeLineEditPrivate::init()
                     this, SLOT(slotPopupCompletion(QString)));
             connect(box, &KCompletionBox::userCancelled,
                     this, &AddresseeLineEditPrivate::slotUserCancelled);
-            connect(s_static->ldapTimer, &QTimer::timeout, this, &AddresseeLineEditPrivate::slotStartLDAPLookup);
-            connect(s_static->ldapSearch, SIGNAL(searchData(KLDAP::LdapResult::List)),
+            connect(AddresseeLineEditManager::self()->ldapTimer(), &QTimer::timeout, this, &AddresseeLineEditPrivate::slotStartLDAPLookup);
+            connect(AddresseeLineEditManager::self()->ldapSearch(), SIGNAL(searchData(KLDAP::LdapResult::List)),
                     SLOT(slotLDAPSearchData(KLDAP::LdapResult::List)));
 
             m_completionInitialized = true;
@@ -207,31 +168,6 @@ void AddresseeLineEditPrivate::setIcon(const QIcon &icon, const QString &tooltip
     }
 }
 
-void AddresseeLineEditPrivate::startLoadingLDAPEntries()
-{
-    QString text(s_static->ldapText);
-
-    // TODO cache last?
-    QString prevAddr;
-    const int index = text.lastIndexOf(QLatin1Char(','));
-    if (index >= 0) {
-        prevAddr = text.left(index + 1) + QLatin1Char(' ');
-        text = text.mid(index + 1, 255).trimmed();
-    }
-
-    if (text.isEmpty()) {
-        return;
-    }
-
-    s_static->ldapSearch->startSearch(text);
-}
-
-void AddresseeLineEditPrivate::stopLDAPLookup()
-{
-    s_static->ldapSearch->cancelSearch();
-    s_static->ldapLineEdit = nullptr;
-}
-
 QStringList AddresseeLineEdit::cleanupEmailList(const QStringList &inputList)
 {
     return d->cleanupEmailList(inputList);
@@ -253,11 +189,9 @@ void AddresseeLineEditPrivate::searchInBaloo()
     Akonadi::Search::PIM::ContactCompleter com(trimmedString, 20);
     const QStringList listEmail = cleanupEmailList(com.complete());
     for (const QString &email : listEmail) {
-        addCompletionItem(email, 1, s_static->balooCompletionSource);
+        addCompletionItem(email, 1, AddresseeLineEditManager::self()->balooCompletionSource());
     }
     doCompletion(m_lastSearchMode);
-    //  if ( q->hasFocus() || q->completionBox()->hasFocus() ) {
-    //}
 }
 
 void AddresseeLineEditPrivate::alternateColor()
@@ -270,9 +204,8 @@ void AddresseeLineEditPrivate::setCompletedItems(const QStringList &items, bool
 {
     KCompletionBox *completionBox = q->completionBox();
 
-    if (!items.isEmpty() &&
-            !(items.count() == 1 && m_searchString == items.first())) {
-
+    if (!items.isEmpty()
+        && !(items.count() == 1 && m_searchString == items.first())) {
         completionBox->clear();
         const int numberOfItems(items.count());
         for (int i = 0; i < numberOfItems; ++i) {
@@ -281,7 +214,7 @@ void AddresseeLineEditPrivate::setCompletedItems(const QStringList &items, bool
                 if (!m_alternateColor.isValid()) {
                     alternateColor();
                 }
-                item->setFlags(item->flags() & ~ Qt::ItemIsSelectable);
+                item->setFlags(item->flags() & ~Qt::ItemIsSelectable);
                 item->setBackgroundColor(m_alternateColor);
             }
             completionBox->addItem(item);
@@ -294,7 +227,7 @@ void AddresseeLineEditPrivate::setCompletedItems(const QStringList &items, bool
             // we have to install the event filter after popup(), since that
             // calls show(), and that's where KCompletionBox installs its filter.
             // We want to be first, though, so do it now.
-            if (s_static->completion->order() == KCompletion::Weighted) {
+            if (AddresseeLineEditManager::self()->completion()->order() == KCompletion::Weighted) {
                 qApp->installEventFilter(q);
             }
         }
@@ -321,35 +254,33 @@ void AddresseeLineEditPrivate::setCompletedItems(const QStringList &items, bool
     }
 }
 
-void AddresseeLineEditPrivate::addCompletionItem(const QString &string, int weight,
-        int completionItemSource,
-        const QStringList *keyWords)
+void AddresseeLineEditPrivate::addCompletionItem(const QString &string, int weight, int completionItemSource, const QStringList *keyWords)
 {
     // Check if there is an exact match for item already, and use the
     // maximum weight if so. Since there's no way to get the information
     // from KCompletion, we have to keep our own QMap.
     // We also update the source since the item should always be shown from the source with the highest weight
 
-    AddresseeLineEditStatic::CompletionItemsMap::iterator it = s_static->completionItemMap.find(string);
-    if (it != s_static->completionItemMap.end()) {
+    AddresseeLineEditManager::CompletionItemsMap::iterator it = AddresseeLineEditManager::self()->completionItemMap.find(string);
+    if (it != AddresseeLineEditManager::self()->completionItemMap.end()) {
         weight = qMax((*it).first, weight);
         (*it).first = weight;
         (*it).second = completionItemSource;
     } else {
-        s_static->completionItemMap.insert(string, qMakePair(weight, completionItemSource));
+        AddresseeLineEditManager::self()->completionItemMap.insert(string, qMakePair(weight, completionItemSource));
     }
 
-    s_static->completion->addItem(string, weight);
+    AddresseeLineEditManager::self()->completion()->addItem(string, weight);
     if (keyWords && !keyWords->isEmpty()) {
-        s_static->completion->addItemWithKeys(string, weight, keyWords);    // see kmailcompletion.cpp
+        AddresseeLineEditManager::self()->completion()->addItemWithKeys(string, weight, keyWords);    // see kmailcompletion.cpp
     }
 }
 
 const QStringList KPIM::AddresseeLineEditPrivate::adjustedCompletionItems(bool fullSearch)
 {
-    QStringList items = fullSearch ?
-                        s_static->completion->allMatches(m_searchString) :
-                        s_static->completion->substringCompletion(m_searchString);
+    QStringList items = fullSearch
+                        ? AddresseeLineEditManager::self()->completion()->allMatches(m_searchString)
+                        : AddresseeLineEditManager::self()->completion()->substringCompletion(m_searchString);
 
     //force items to be sorted by email
     items.sort();
@@ -371,16 +302,16 @@ const QStringList KPIM::AddresseeLineEditPrivate::adjustedCompletionItems(bool f
     QMap<int, QStringList> sections;
     QStringList sortedItems;
     for (QStringList::Iterator it = items.begin(); it != items.end(); ++it, ++i) {
-        AddresseeLineEditStatic::CompletionItemsMap::const_iterator cit = s_static->completionItemMap.constFind(*it);
-        if (cit == s_static->completionItemMap.constEnd()) {
+        AddresseeLineEditManager::CompletionItemsMap::const_iterator cit = AddresseeLineEditManager::self()->completionItemMap.constFind(*it);
+        if (cit == AddresseeLineEditManager::self()->completionItemMap.constEnd()) {
             continue;
         }
 
         const int index = (*cit).second;
 
-        if (s_static->completion->order() == KCompletion::Weighted) {
+        if (AddresseeLineEditManager::self()->completion()->order() == KCompletion::Weighted) {
             if (lastSourceIndex == -1 || lastSourceIndex != index) {
-                const QString sourceLabel(s_static->completionSources.at(index));
+                const QString sourceLabel(AddresseeLineEditManager::self()->completionSources.at(index));
                 if (sections.find(index) == sections.end()) {
                     it = items.insert(it, sourceLabel);
                     ++it; //skip new item
@@ -394,26 +325,25 @@ const QStringList KPIM::AddresseeLineEditPrivate::adjustedCompletionItems(bool f
         }
         sections[ index ].append(*it);
 
-        if (s_static->completion->order() == KCompletion::Sorted) {
+        if (AddresseeLineEditManager::self()->completion()->order() == KCompletion::Sorted) {
             sortedItems.append(*it);
         }
     }
 
-    if (s_static->completion->order() == KCompletion::Weighted) {
-
+    if (AddresseeLineEditManager::self()->completion()->order() == KCompletion::Weighted) {
         // Sort the sections
         QList<SourceWithWeight> sourcesAndWeights;
-        const int numberOfCompletionSources(s_static->completionSources.size());
+        const int numberOfCompletionSources(AddresseeLineEditManager::self()->completionSources.count());
         sourcesAndWeights.reserve(numberOfCompletionSources);
         for (int i = 0; i < numberOfCompletionSources; ++i) {
             SourceWithWeight sww;
-            sww.sourceName = s_static->completionSources.at(i);
-            sww.weight = s_static->completionSourceWeights[sww.sourceName];
+            sww.sourceName = AddresseeLineEditManager::self()->completionSources.at(i);
+            sww.weight = AddresseeLineEditManager::self()->completionSourceWeights[sww.sourceName];
             sww.index = i;
             sourcesAndWeights.append(sww);
         }
 
-        qSort(sourcesAndWeights.begin(), sourcesAndWeights.end());
+        std::sort(sourcesAndWeights.begin(), sourcesAndWeights.end());
         // Add the sections and their items to the final sortedItems result list
         const int numberOfSources(sourcesAndWeights.size());
         for (int i = 0; i < numberOfSources; ++i) {
@@ -446,8 +376,8 @@ void AddresseeLineEditPrivate::updateSearchString()
             inQuote = !inQuote;
         }
 
-        if (searchChar == QLatin1Char('\\') &&
-                (i + 1) < searchStringLength && m_searchString.at(i + 1) == QLatin1Char('"')) {
+        if (searchChar == QLatin1Char('\\')
+            && (i + 1) < searchStringLength && m_searchString.at(i + 1) == QLatin1Char('"')) {
             ++i;
         }
 
@@ -455,9 +385,9 @@ void AddresseeLineEditPrivate::updateSearchString()
             continue;
         }
 
-        if (i < searchStringLength &&
-                (searchChar == QLatin1Char(',') ||
-                 (m_useSemicolonAsSeparator && searchChar == QLatin1Char(';')))) {
+        if (i < searchStringLength
+            && (searchChar == QLatin1Char(',')
+                || (m_useSemicolonAsSeparator && searchChar == QLatin1Char(';')))) {
             n = i;
         }
     }
@@ -481,7 +411,8 @@ void AddresseeLineEditPrivate::updateSearchString()
 
 void AddresseeLineEditPrivate::slotTriggerDelayedQueries()
 {
-    if (m_searchString.isEmpty() || m_searchString.trimmed().size() <= 2) {
+    const QString strSearch = m_searchString.trimmed();
+    if (strSearch.size() <= 2) {
         return;
     }
 
@@ -508,15 +439,15 @@ void AddresseeLineEditPrivate::akonadiPerformSearch()
     qCDebug(LIBKDEPIMAKONADI_LOG) << "searching akonadi with:" << m_searchString;
 
     // first, kill all job still in flight, they are no longer current
-    for (const QWeakPointer<Akonadi::Job> &job : qAsConst(s_static->akonadiJobsInFlight)) {
+    for (const QWeakPointer<Akonadi::Job> &job : qAsConst(AddresseeLineEditManager::self()->akonadiJobsInFlight)) {
         if (!job.isNull()) {
             job.data()->kill();
         }
     }
-    s_static->akonadiJobsInFlight.clear();
+    AddresseeLineEditManager::self()->akonadiJobsInFlight.clear();
 
     // now start new jobs
-    Akonadi::ContactSearchJob *contactJob = new Akonadi::ContactSearchJob(s_static->akonadiSession());
+    Akonadi::ContactSearchJob *contactJob = new Akonadi::ContactSearchJob(AddresseeLineEditManager::self()->akonadiSession());
     contactJob->fetchScope().setAncestorRetrieval(Akonadi::ItemFetchScope::Parent);
     contactJob->setQuery(Akonadi::ContactSearchJob::NameOrEmail, m_searchString,
                          Akonadi::ContactSearchJob::ContainsWordBoundaryMatch);
@@ -525,7 +456,7 @@ void AddresseeLineEditPrivate::akonadiPerformSearch()
     connect(contactJob, &KJob::result,
             this, &AddresseeLineEditPrivate::slotAkonadiSearchResult);
 
-    Akonadi::ContactGroupSearchJob *groupJob = new Akonadi::ContactGroupSearchJob(s_static->akonadiSession());
+    Akonadi::ContactGroupSearchJob *groupJob = new Akonadi::ContactGroupSearchJob(AddresseeLineEditManager::self()->akonadiSession());
     groupJob->fetchScope().setAncestorRetrieval(Akonadi::ItemFetchScope::Parent);
     groupJob->setQuery(Akonadi::ContactGroupSearchJob::Name, m_searchString,
                        Akonadi::ContactGroupSearchJob::ContainsMatch);
@@ -534,28 +465,28 @@ void AddresseeLineEditPrivate::akonadiPerformSearch()
     connect(groupJob, &KJob::result,
             this, &AddresseeLineEditPrivate::slotAkonadiSearchResult);
 
-    s_static->akonadiJobsInFlight.append(contactJob);
-    s_static->akonadiJobsInFlight.append(groupJob);
+    AddresseeLineEditManager::self()->akonadiJobsInFlight.append(contactJob);
+    AddresseeLineEditManager::self()->akonadiJobsInFlight.append(groupJob);
     akonadiHandlePending();
 }
 
 void AddresseeLineEditPrivate::akonadiHandlePending()
 {
-    qCDebug(LIBKDEPIMAKONADI_LOG) << "Pending items: " << s_static->akonadiPendingItems.size();
-    Akonadi::Item::List::iterator it = s_static->akonadiPendingItems.begin();
-    while (it != s_static->akonadiPendingItems.end()) {
+    qCDebug(LIBKDEPIMAKONADI_LOG) << "Pending items: " << AddresseeLineEditManager::self()->akonadiPendingItems.size();
+    Akonadi::Item::List::iterator it = AddresseeLineEditManager::self()->akonadiPendingItems.begin();
+    while (it != AddresseeLineEditManager::self()->akonadiPendingItems.end()) {
         const Akonadi::Item item = *it;
 
-        const AddresseeLineEditStatic::collectionInfo sourceIndex =
-            s_static->akonadiCollectionToCompletionSourceMap.value(item.parentCollection().id(), AddresseeLineEditStatic::collectionInfo());
+        const AddresseeLineEditManager::collectionInfo sourceIndex
+            = AddresseeLineEditManager::self()->akonadiCollectionToCompletionSourceMap.value(item.parentCollection().id(), AddresseeLineEditManager::collectionInfo());
         if (sourceIndex.index >= 0) {
-            qCDebug(LIBKDEPIMAKONADI_LOG) << "identified collection: " << s_static->completionSources[sourceIndex.index];
+            qCDebug(LIBKDEPIMAKONADI_LOG) << "identified collection: " << AddresseeLineEditManager::self()->completionSources[sourceIndex.index];
             if (sourceIndex.enabled) {
                 q->addItem(item, 1, sourceIndex.index);
             }
 
             // remove from the pending
-            it = s_static->akonadiPendingItems.erase(it);
+            it = AddresseeLineEditManager::self()->akonadiPendingItems.erase(it);
         } else {
             ++it;
         }
@@ -572,7 +503,7 @@ void AddresseeLineEditPrivate::doCompletion(bool ctrlT)
         return;
     }
 
-    s_static->completion->setOrder(KCompletion::Weighted);
+    AddresseeLineEditManager::self()->completion()->setOrder(KCompletion::Weighted);
 
     // cursor at end of string - or Ctrl+T pressed for substring completion?
     if (ctrlT) {
@@ -591,36 +522,39 @@ void AddresseeLineEditPrivate::doCompletion(bool ctrlT)
     }
 
     switch (mode) {
-    case KCompletion::CompletionPopupAuto: {
+    case KCompletion::CompletionPopupAuto:
         if (m_searchString.isEmpty()) {
             break;
         }
-        //else: fall-through to the CompletionPopup case
-    }
+    //else: fall-through to the CompletionPopup case
+#if QT_VERSION >= QT_VERSION_CHECK(5,8,0)
+        Q_FALLTHROUGH();
+#endif
 
-    case KCompletion::CompletionPopup: {
+    case KCompletion::CompletionPopup:
+    {
         const QStringList items = adjustedCompletionItems(false);
         setCompletedItems(items, false);
+        break;
     }
-    break;
 
-    case KCompletion::CompletionShell: {
-        const QString match = s_static->completion->makeCompletion(m_searchString);
+    case KCompletion::CompletionShell:
+    {
+        const QString match = AddresseeLineEditManager::self()->completion()->makeCompletion(m_searchString);
         if (!match.isNull() && match != m_searchString) {
             q->setText(m_previousAddresses + match);
             q->setModified(true);
             q->cursorAtEnd();
         }
+        break;
     }
-    break;
 
     case KCompletion::CompletionMan: // Short-Auto in fact
-    case KCompletion::CompletionAuto: {
+    case KCompletion::CompletionAuto:
         //force autoSuggest in KLineEdit::keyPressed or setCompletedText will have no effect
         q->setCompletionMode(q->completionMode());
 
         if (!m_searchString.isEmpty()) {
-
             //if only our \" is left, remove it since user has not typed it either
             if (m_searchExtended && m_searchString == QLatin1String("\"")) {
                 m_searchExtended = false;
@@ -629,17 +563,17 @@ void AddresseeLineEditPrivate::doCompletion(bool ctrlT)
                 break;
             }
 
-            QString match = s_static->completion->makeCompletion(m_searchString);
+            QString match = AddresseeLineEditManager::self()->completion()->makeCompletion(m_searchString);
 
             if (!match.isEmpty()) {
                 if (match != m_searchString) {
-                    QString adds = m_previousAddresses + match;
+                    const QString adds = m_previousAddresses + match;
                     q->callSetCompletedText(adds);
                 }
             } else {
                 if (!m_searchString.startsWith(QLatin1Char('\"'))) {
                     //try with quoted text, if user has not type one already
-                    match = s_static->completion->makeCompletion(QLatin1String("\"") + m_searchString);
+                    match = AddresseeLineEditManager::self()->completion()->makeCompletion(QLatin1String("\"") + m_searchString);
                     if (!match.isEmpty() && match != m_searchString) {
                         m_searchString = QLatin1String("\"") + m_searchString;
                         m_searchExtended = true;
@@ -652,7 +586,7 @@ void AddresseeLineEditPrivate::doCompletion(bool ctrlT)
                     m_searchExtended = false;
                     q->setText(m_previousAddresses + m_searchString);
                     //now try again
-                    match = s_static->completion->makeCompletion(m_searchString);
+                    match = AddresseeLineEditManager::self()->completion()->makeCompletion(m_searchString);
                     if (!match.isEmpty() && match != m_searchString) {
                         const QString adds = m_previousAddresses + match;
                         q->setCompletedText(adds);
@@ -660,8 +594,7 @@ void AddresseeLineEditPrivate::doCompletion(bool ctrlT)
                 }
             }
         }
-    }
-    break;
+        break;
 
     case KCompletion::CompletionNone:
     default: // fall through
@@ -700,31 +633,30 @@ void AddresseeLineEditPrivate::slotPopupCompletion(const QString &completion)
 void AddresseeLineEditPrivate::slotReturnPressed(const QString &)
 {
     if (!q->completionBox()->selectedItems().isEmpty()) {
-        slotPopupCompletion(q->completionBox()->selectedItems().first()->text());
+        slotPopupCompletion(q->completionBox()->selectedItems().constFirst()->text());
     }
 }
 
 void AddresseeLineEditPrivate::slotStartLDAPLookup()
 {
-    if (s_networkConfigMgr->isOnline()) {
-
+    if (AddresseeLineEditManager::self()->isOnline()) {
         const KCompletion::CompletionMode mode = q->completionMode();
         if (mode == KCompletion::CompletionNone) {
             return;
         }
-        if (!s_static->ldapSearch->isAvailable()) {
+        if (!AddresseeLineEditManager::self()->ldapSearch()->isAvailable()) {
             return;
         }
-        if (s_static->ldapLineEdit != q) {
+        if (AddresseeLineEditManager::self()->addressLineEdit() != q) {
             return;
         }
-        startLoadingLDAPEntries();
+        AddresseeLineEditManager::self()->startLoadingLDAPEntries();
     }
 }
 
 void AddresseeLineEditPrivate::slotLDAPSearchData(const KLDAP::LdapResult::List &results)
 {
-    if (results.isEmpty() || s_static->ldapLineEdit != q) {
+    if (results.isEmpty() || AddresseeLineEditManager::self()->addressLineEdit() != q) {
         return;
     }
 
@@ -745,17 +677,17 @@ void AddresseeLineEditPrivate::slotLDAPSearchData(const KLDAP::LdapResult::List
             }
         }
 
-        if (!s_static->ldapClientToCompletionSourceMap.contains(result.clientNumber)) {
-            s_static->updateLDAPWeights(); // we got results from a new source, so update the completion sources
+        if (!AddresseeLineEditManager::self()->isLdapClientToCompletionSourceMapContains(result.clientNumber)) {
+            AddresseeLineEditManager::self()->updateLDAPWeights(); // we got results from a new source, so update the completion sources
         }
 
         q->addContact(contact, result.completionWeight,
-                      s_static->ldapClientToCompletionSourceMap[ result.clientNumber ], ou);
+                      AddresseeLineEditManager::self()->ldapClientToCompletionSourceValue(result.clientNumber), ou);
     }
 
-    if ((q->hasFocus() || q->completionBox()->hasFocus()) &&
-            q->completionMode() != KCompletion::CompletionNone &&
-            q->completionMode() != KCompletion::CompletionShell) {
+    if ((q->hasFocus() || q->completionBox()->hasFocus())
+        && q->completionMode() != KCompletion::CompletionNone
+        && q->completionMode() != KCompletion::CompletionShell) {
         q->setText(m_previousAddresses + m_searchString);
         // only complete again if the user didn't change the selection while
         // we were waiting; otherwise the completion box will be closed
@@ -768,22 +700,26 @@ void AddresseeLineEditPrivate::slotLDAPSearchData(const KLDAP::LdapResult::List
 
 void AddresseeLineEditPrivate::slotEditCompletionOrder()
 {
-    init(); // for s_static->ldapSearch
+    init(); // for AddresseeLineEditStatic::self()->ldapSearch
     if (m_useCompletion) {
-        s_static->slotEditCompletionOrder();
+        QPointer<CompletionOrderEditor> dlg = new CompletionOrderEditor(AddresseeLineEditManager::self()->ldapSearch(), nullptr);
+        if (dlg->exec()) {
+            AddresseeLineEditManager::self()->updateCompletionOrder();
+        }
+        delete dlg;
     }
 }
 
 KLDAP::LdapClientSearch *AddresseeLineEditPrivate::ldapSearch()
 {
-    init(); // for s_static->ldapSearch
-    return s_static->ldapSearch;
+    init(); // for AddresseeLineEditStatic::self()->ldapSearch
+    return AddresseeLineEditManager::self()->ldapSearch();
 }
 
 void AddresseeLineEditPrivate::slotUserCancelled(const QString &cancelText)
 {
-    if (s_static->ldapSearch && s_static->ldapLineEdit == q) {
-        stopLDAPLookup();
+    if (AddresseeLineEditManager::self()->ldapSearch() && AddresseeLineEditManager::self()->addressLineEdit() == q) {
+        AddresseeLineEditManager::self()->stopLDAPLookup();
     }
 
     q->callUserCancelled(m_previousAddresses + cancelText);   // in KLineEdit
@@ -794,29 +730,29 @@ void AddresseeLineEditPrivate::slotAkonadiHandleItems(const Akonadi::Item::List
     /* We have to fetch the collections of the items, so that
        the source name can be correctly labeled.*/
     for (const Akonadi::Item &item : items) {
-
         // check the local cache of collections
-        const AddresseeLineEditStatic::collectionInfo sourceIndex =
-            s_static->akonadiCollectionToCompletionSourceMap.value(item.parentCollection().id(), AddresseeLineEditStatic::collectionInfo());
+        const Akonadi::Collection::Id colId = item.parentCollection().id();
+        const AddresseeLineEditManager::collectionInfo sourceIndex
+            = AddresseeLineEditManager::self()->akonadiCollectionToCompletionSourceMap.value(colId, AddresseeLineEditManager::collectionInfo());
         if (sourceIndex.index == -1) {
-            qCDebug(LIBKDEPIMAKONADI_LOG) << "Fetching New collection: " << item.parentCollection().id();
+            qCDebug(LIBKDEPIMAKONADI_LOG) << "Fetching New collection: " << colId;
             // the collection isn't there, start the fetch job.
-            Akonadi::CollectionFetchJob *collectionJob =
-                new Akonadi::CollectionFetchJob(item.parentCollection(),
-                                                Akonadi::CollectionFetchJob::Base,
-                                                s_static->akonadiSession());
+            Akonadi::CollectionFetchJob *collectionJob
+                = new Akonadi::CollectionFetchJob(item.parentCollection(),
+                                                  Akonadi::CollectionFetchJob::Base,
+                                                  AddresseeLineEditManager::self()->akonadiSession());
             connect(collectionJob, &Akonadi::CollectionFetchJob::collectionsReceived,
                     this, &AddresseeLineEditPrivate::slotAkonadiCollectionsReceived);
             /* we don't want to start multiple fetch jobs for the same collection,
             so insert the collection with an index value of -2 */
-            AddresseeLineEditStatic::collectionInfo info;
+            AddresseeLineEditManager::collectionInfo info;
             info.index = -2;
-            s_static->akonadiCollectionToCompletionSourceMap.insert(item.parentCollection().id(), info);
-            s_static->akonadiPendingItems.append(item);
+            AddresseeLineEditManager::self()->akonadiCollectionToCompletionSourceMap.insert(colId, info);
+            AddresseeLineEditManager::self()->akonadiPendingItems.append(item);
         } else if (sourceIndex.index == -2) {
             /* fetch job already started, don't need to start another one,
             so just append the item as pending */
-            s_static->akonadiPendingItems.append(item);
+            AddresseeLineEditManager::self()->akonadiPendingItems.append(item);
         } else {
             if (sourceIndex.enabled) {
                 q->addItem(item, 1, sourceIndex.index);
@@ -836,13 +772,10 @@ void AddresseeLineEditPrivate::slotAkonadiSearchResult(KJob *job)
 {
     if (job->error()) {
         qCWarning(LIBKDEPIMAKONADI_LOG) << "Akonadi search job failed: " << job->errorString();
-    } else {
-        Akonadi::ItemSearchJob *searchJob = static_cast<Akonadi::ItemSearchJob *>(job);
-        qCDebug(LIBKDEPIMAKONADI_LOG) << "Found" << searchJob->items().size() << "items";
     }
-    const int index = s_static->akonadiJobsInFlight.indexOf(qobject_cast<Akonadi::Job *>(job));
+    const int index = AddresseeLineEditManager::self()->akonadiJobsInFlight.indexOf(qobject_cast<Akonadi::Job *>(job));
     if (index != -1) {
-        s_static->akonadiJobsInFlight.remove(index);
+        AddresseeLineEditManager::self()->akonadiJobsInFlight.remove(index);
     }
 }
 
@@ -855,13 +788,12 @@ void AddresseeLineEditPrivate::slotAkonadiCollectionsReceived(
     for (const Akonadi::Collection &collection : collections) {
         if (collection.isValid()) {
             const QString sourceString = collection.displayName();
-            const int weight = groupCompletionWeights.readEntry(QString::number(collection.id()), 1);
+            const Akonadi::Collection::Id colId = collection.id();
+            const int weight = groupCompletionWeights.readEntry(QString::number(colId), 1);
             const int index = q->addCompletionSource(sourceString, weight);
-            AddresseeLineEditStatic::collectionInfo info;
-            info.index = index;
-            info.enabled = groupCompletionEnabled.readEntry(QString::number(collection.id()), true);
-            qCDebug(LIBKDEPIMAKONADI_LOG) << "\treceived: " << sourceString << "index: " << index;
-            s_static->akonadiCollectionToCompletionSourceMap.insert(collection.id(), info);
+            AddresseeLineEditManager::collectionInfo info(index, groupCompletionEnabled.readEntry(QString::number(colId), true));
+            qCDebug(LIBKDEPIMAKONADI_LOG) << "\treceived: " << sourceString << "index: " << index << " enabled: " << info.enabled;
+            AddresseeLineEditManager::self()->akonadiCollectionToCompletionSourceMap.insert(colId, info);
         }
     }
 
@@ -887,22 +819,12 @@ void AddresseeLineEditPrivate::updateBalooBlackList()
 {
     loadBalooBlackList();
     q->removeCompletionSource(i18nc("@title:group", "Contacts found in your data"));
-    s_static->balooCompletionSource = q->addCompletionSource(i18nc("@title:group", "Contacts found in your data"), -1);
+    AddresseeLineEditManager::self()->setBalooCompletionSource(q->addCompletionSource(i18nc("@title:group", "Contacts found in your data"), -1));
 }
 
 void AddresseeLineEditPrivate::updateCompletionOrder()
 {
-    s_static->updateCompletionOrder();
-}
-
-void AddresseeLineEditPrivate::slotConfigureBalooBlackList()
-{
-    QPointer<KPIM::BlackListBalooEmailCompletionDialog> dlg = new KPIM::BlackListBalooEmailCompletionDialog(q);
-    dlg->setEmailBlackList(m_balooBlackList);
-    if (dlg->exec()) {
-        updateBalooBlackList();
-    }
-    delete dlg;
+    AddresseeLineEditManager::self()->updateCompletionOrder();
 }
 
 bool AddresseeLineEditPrivate::canDeleteLineEdit() const
@@ -1075,12 +997,12 @@ void AddresseeLineEditPrivate::loadBalooBlackList()
 
 void AddresseeLineEditPrivate::removeCompletionSource(const QString &source)
 {
-    s_static->removeCompletionSource(source);
+    AddresseeLineEditManager::self()->removeCompletionSource(source);
 }
 
 int AddresseeLineEditPrivate::addCompletionSource(const QString &source, int weight)
 {
-    return s_static->addCompletionSource(source, weight);
+    return AddresseeLineEditManager::self()->addCompletionSource(source, weight);
 }
 
 void AddresseeLineEditPrivate::mightBeGroupJobsClear()
@@ -1117,5 +1039,4 @@ void AddresseeLineEditPrivate::mightBeGroupJobsAdd(Akonadi::ContactGroupSearchJo
 {
     mMightBeGroupJobs.append(job);
 }
-
 }
